==> mc-4.8.13.tar.xz: mc-4.8.13/doc/hints/l10n/mc.hint.cs <==
Tip: C-x t vloží na příkazovou řádku označené soubory.

Tip: C-x p vloží na příkazovou řádku jméno aktuálního adresáře.

Tip: Doplňování: použijte M-Tab (nebo Esc+Tab). Dvojitým zadáním získáte
seznam.

Tip: Použitím M-p nebo M-n se pohybujete v historii příkazů.

Tip: Chcete zadat speciální znak (např. tabulátor)? Použijte Ctrl-q a daný
znak.

Tip: Nechcete již vidět tipy? Vypněte je v Nastavení/Zobrazení/Další
nastavení.

Tip: Adresáře vyberete přidáním lomítka na konec vzorku.

Tip: Pokud Váš terminál nezná nebo nemá funkční klávesy, použijte Esc+číslo.

Tip: Stránka GNU Midnight Commanderu je http://www.midnight-commander.org/

Tip: Zprávy o chybách posílejte na mc-devel@gnome.org (anglicky).

Tip: Pomocí klávesy Tab změníte aktuální panel.

Tip: Stiskem Enter na souboru .tar nebo .tar.gz si prohlédnete obsah.

Tip: Existuje také manuálová stránka [mc(1)].

Tip: Přejete si klávesy stejně jako v lynxu? Nastavte to v Nastavení.

Tip: Makra uvozená % pracují na příkazové řádce.

Tip: Pomocí M-! můžete spustit příkaz a prohlédnout si výstup v okně.

Tip: Zobrazení v panelech může být upraveno. Z „man mc“ se dozvíte více.

Tip: %D/%T se rozvine na soubory označené v druhém panelu.

Tip: Chcete opět váš shell? Stiskněte C-o. Do MC se vrátíte opět přes C-o.

Tip: Nastavením proměnné CDPATH můžete šetřit klávesnici.

Tip: Pokud chcete vidět soubory začínající tečkou, řekněte to v Nastavení.

Tip: Chcete vidět zálohy svých souborů (končí ~). Použijte Nastavení.

Tip: Doplňování funguje ve vstupních řádkách všech dialogů. Použijte M-Tab.

Tip: Na terminálech s pomalou odezvou zkuste parametr -s (mc -s).

Tip: S nalezenými soubory můžete pracovat. Stiskněte tlačítko Panelizace.

Tip: Pro opravdu složité operace zkuste příkaz Příkaz/Externí panelizace.

Tip: Pokud chcete změnit adresář při práci na příkazové řádce, zkuste M-c.

Pozn.: Příkazy shellu nefungují, pokud nepracujete na lokálním systému
souborů.

Tip: Smazaný text obnovíte C-y.

Tip: Pokud některé klávesy nefungují, použijte menu Nastavení/Učení kláves.

Tip: K zobrazení výstupu příkazu v okně použijte M-!

Tip: F13 (nebo Shift-F3) vyvolá prohlížení bez zpracování obsahu souboru.

Tip: Editor pro klávesu F4 určíte pomocí proměnné prostředí EDITOR.

Tip: Externí prohlížeč určíte proměnnými VIEWER nebo PAGER

Tip: Všechny žádosti o potvrzení můžete zakázat v Nastavení/Potvrzování.

Hint: Leap to frequently used directories in a single bound with C-.

Tip: Na anonymní FTP se připojíte pomocí „cd ftp://stroj.domena.cz“.

Tip: MC má vestavěný FTP. Podívejte se do menu Levý/FTP spojení na počítač.

Tip: M-t rychle mění formát zobrazení panelů.

Tip: Při FTP spojení můžete zadat i jméno: „cd ftp://jmeno@stroj.domena.cz“.

Tip: RPM soubory si prohlédnete stiskem Enter.

Tip: Pro označení adresářů v dialogovém okně výběru souborů, přidejte
lomítko.

Tip: Chcete-li použít myš pro zkopírování nebo vložení textu, stiskněte
Shift.

Hint: Key frequently visited ftp sites in the hotlist: type C-.

==> mc_4.8.19.orig.tar.xz: mc-4.8.19/doc/hints/l10n/mc.hint.cs <==
Tip: C-x t vloží na příkazovou řádku označené soubory.

Tip: C-x p vloží na příkazovou řádku jméno aktuálního adresáře.

Tip: Doplňování: použijte M-Tab (nebo Esc+Tab). Dvojitým zadáním získáte
seznam.

Tip: Použitím M-p nebo M-n se pohybujete v historii příkazů.

Tip: Chcete zadat speciální znak (např. tabulátor)? Použijte Ctrl-q a daný
znak.

Tip: Nechcete již vidět tipy? Vypněte je v Nastavení/Zobrazení/Další
nastavení.

Tip: Adresáře vyberete přidáním lomítka na konec vzorku.

Tip: Pokud Váš terminál nezná nebo nemá funkční klávesy, použijte Esc+číslo.

Tip: Stránka GNU Midnight Commanderu je http://www.midnight-commander.org/

Tip: Zprávy o chybách posílejte na mc-devel@gnome.org (anglicky).

Tip: Pomocí klávesy Tab změníte aktuální panel.

Tip: Stiskem Enter na souboru .tar nebo .tar.gz si prohlédnete obsah.

Tip: Existuje také manuálová stránka [mc(1)].

Hint: Do you want Lynx-style navigation? Set it in the Configuration dialog.

Tip: Makra uvozená % pracují na příkazové řádce.

Tip: Pomocí M-! můžete spustit příkaz a prohlédnout si výstup v okně.

Tip: Zobrazení v panelech může být upraveno. Z „man mc“ se dozvíte více.

Tip: %D/%T se rozvine na soubory označené v druhém panelu.

Tip: Chcete opět váš shell? Stiskněte C-o. Do MC se vrátíte opět přes C-o.

Tip: Nastavením proměnné CDPATH můžete šetřit klávesnici.

Tip: Pokud chcete vidět soubory začínající tečkou, řekněte to v Nastavení.

Tip: Chcete vidět zálohy svých souborů (končí ~). Použijte Nastavení.

Tip: Doplňování funguje ve vstupních řádkách všech dialogů. Použijte M-Tab.

Tip: Na terminálech s pomalou odezvou zkuste parametr -s (mc -s).

Tip: S nalezenými soubory můžete pracovat. Stiskněte tlačítko Panelizace.

Tip: Pro opravdu složité operace zkuste příkaz Příkaz/Externí panelizace.

Tip: Pokud chcete změnit adresář při práci na příkazové řádce, zkuste M-c.

Pozn.: Příkazy shellu nefungují, pokud nepracujete na lokálním systému
souborů.

Tip: Smazaný text obnovíte C-y.

Tip: Pokud některé klávesy nefungují, použijte menu Nastavení/Učení kláves.

Tip: K zobrazení výstupu příkazu v okně použijte M-!

Tip: F13 (nebo Shift-F3) vyvolá prohlížení bez zpracování obsahu souboru.

Tip: Editor pro klávesu F4 určíte pomocí proměnné prostředí EDITOR.

Tip: Externí prohlížeč určíte proměnnými VIEWER nebo PAGER

Tip: Všechny žádosti o potvrzení můžete zakázat v Nastavení/Potvrzování.

Hint: Leap to frequently used directories in a single bound with C-.

Tip: Na anonymní FTP se připojíte pomocí „cd ftp://stroj.domena.cz“.

Tip: MC má vestavěný FTP. Podívejte se do menu Levý/FTP spojení na počítač.

Tip: M-t rychle mění formát zobrazení panelů.

Tip: Při FTP spojení můžete zadat i jméno: „cd ftp://jmeno@stroj.domena.cz“.

Tip: RPM soubory si prohlédnete stiskem Enter.

Tip: Pro označení adresářů v dialogovém okně výběru souborů, přidejte
lomítko.

Tip: Chcete-li použít myš pro zkopírování nebo vložení textu, stiskněte
Shift.

Hint: Key frequently visited ftp sites in the hotlist: type C-.
